from pprint import saferepr

class row(object):
    def __init__(self, desc, data):
        object.__init__(self)
        self.__rawdata = data
        self.__data = dict(zip([x[0] for x in desc], data))

    def __getitem__(self, key):
        try:
            return self.__data[key]
        except KeyError:
            try:
                return self.__rawdata[key]
            except KeyError:
                raise KeyError, key

    def __getattr__(self, key):
        try:
            return self.__data[key]
        except KeyError:
            raise AttributeError

    def __repr__(self):
        return "row(%s)" % saferepr(self.__data)




from urlparse import urlparse
from .connection import connection

version = (0, 4, 0)

def _connect_mysql(url):
    import MySQLdb as db
    params = {}
    if url.username:
        params["user"] = url.username
    else:
        params["user"] = "root"
    if url.password:
        params["passwd"] = url.password
    if url.hostname:
        params["host"] = url.hostname
    if url.port:
        params["port"] = url.port
    if url.path:
        params["db"] = url.path[1:]
    return connection(db.connect(**params))

DEFAULT_LOOKUP = {
    "mysql": _connect_mysql
}

def connect(url, lookup=None):
    url = urlparse(url)
    if lookup is None:
        lookup = DEFAULT_LOOKUP
    return lookup[url.scheme](url)




#!/usr/bin/env python

try:
    from setuptools import setup, find_packages
except ImportError:
    from ez_setup import use_setuptools
    use_setuptools()
    from setuptools import setup, find_packages

import dbutil

LONG_DESCRIPTION = """A minimal wrapper for the Python DB API 2.0.
"""

setup(name="dbutil",
      version="%d.%d.%d" % dbutil.version,
      description="Minimalist utility functions for the Python DB API",
      long_description=LONG_DESCRIPTION,
      author="Tom Lee",
      author_email="pypi@tomlee.co",
      maintainer="Tom Lee",
      maintainer_email="pypi@tomlee.co",
      url="http://github.com/thomaslee/python-dbutil",
      license="MIT",
      packages=find_packages(),
)



from .row import row

class connection(object):
    def __init__(self, impl):
        object.__init__(self)
        self.impl = impl

    def __getattr__(self, key):
        return getattr(self.impl, key)

    def __enter__(self, *args):
        return self

    def __exit__(self, *args):
        self.impl.close()

    def one(self, query, params=None):
        if params is None:
            params = tuple()
        with self.impl as crs:
            crs.execute(query, params)
            if crs.rowcount == 0:
                return None
            else:
                return crs.fetchone()[0]

    def row(self, query, params=None):
        if params is None:
            params = tuple()
        with self.impl as crs:
            crs.execute(query, params)
            if crs.rowcount == 0:
                return None
            else:
                return row(crs.description, crs.fetchone())

    def all(self, query, params=None):
        if params is None:
            params = tuple()
        with self.impl as crs:
            crs.execute(query, params)
            result = []
            for rec in crs:
                result.append(row(crs.description, rec))
            return result

    def execute(self, query, params=None):
        if params is None:
            params = tuple()
        with self.impl as crs:
            crs.execute(query, params)

    def iter(self, query, params=None):
        if params is None:
            params = tuple()
        with self.impl as crs:
            crs.execute(query, params)
            for rec in crs:
                yield row(crs.description, rec)

    def each(self, cb, query, params=None):
        if params is None:
            params = tuple()
        with self.impl as crs:
            crs.execute(query, params)
            for rec in crs:
                cb(row(crs.description, rec))

    def map(self, cb, query, params=None):
        if params is None:
            params = tuple()
        with self.impl as crs:
            crs.execute(query, params)
            result = []
            for rec in crs:
                result.append(cb(row(crs.description, rec)))
            return result

